{*-----------------------------------------------------------------------+
 |
 |               Copyright (c) Sergey Perevoznik 1998.
 |
 | NAME
 |  rwoci.pas
 |
 | FUNCTION
 |  Oracle Reports OCI Interface - Public Header File
 |
 +----------------------------------------------------------------------*}

Unit RWOCI;

Interface

Uses Windows;

// *----------------------------------------------------------------------+
// | Error Codes for Oracle Reports OCI
// |
// | NOTE: Errors other than these can also be returned based on the
// |       the Operating System. These errors are typically raised during
// |       the transfer of control to the Oracle Reports entry point.
// |
// |       On Windows,  OCI relies on the "system" call to transfer
// |       control to the appropriate OR executable. Error codes returned
// |       by "system" are passed back to the OCI client unaltered.
// |       ERRNO also contains useful information here. See Windows
// |       documentation for more information on "system" call.
// |
// |       On other platforms, the OCI interface relies on an ORACLE
// |       proprietary mechanism to pass control to the appopriate
// |       internal OR entry point.  Non-zero return codes that are
// |       not generic generally indicates either an installation
// |       problem or an OR internal error. Check your installation first.
// |       If problem persists, call support with the error code.
// |
// | NOTE: Errors raised by Oracle Reports (REP-xxxx messages) are *not*
// |       available to OCI clients through this interface at this point.
// |
// |       There is also currently no mechanism to force a specific return
// |       code from the report.
// +----------------------------------------------------------------------*/

// Generic Errors

Const

RWOCI_ERR_BASE       = 3800;
RWOCI_ERR_INITFAILED = 3801; // Internal Error
RWOCI_ERR_UNSUPP_EP  = 3802; // Unsupported Entry Point

// *------------------------------------+
// | Function Prototypes
// +------------------------------------*

//  rwcrun, rw2run - call interface for RUNREP (Reports Runtime char mode)

Function rwcrun(smdline : PChar) : longint ; cdecl;
Function rw2run(smdline : PChar; len : longint) : longint ; cdecl;

// rwcrrb, rw2rrb - call interface for RUNREP (Reports Runtime bitmapped)

Function rwcrrb(smdline : PChar) : longint ; cdecl;
Function rw2rrb(smdline : PChar; len : longint) : longint ; cdecl;

//  rwcsrb, rw2srb - call interface for SQLREP (Reports Designer bitmapped)

Function rwcsrb(smdline : PChar) : longint ; cdecl;
Function rw2srb(smdline : PChar; len : longint) : longint ; cdecl;

// rwccon, rw2con  - call interface for CONVREP (bitmapped)

Function rwccon(smdline : PChar) : longint ; cdecl;
Function rw2con(smdline : PChar; len : longint) : longint ; cdecl;

// rwcmov, rw2mov - call interface for MOVEREP (character mode)

Function rwcmov(smdline : PChar) : longint ; cdecl;
Function rw2mov(smdline : PChar; len : longint) : longint; cdecl;

// rwcsrv, rw2srv - call interface for Report Server (Windows ONLY)

Function rwcsrv(smdline : PChar) : longint ;  cdecl;
Function rw2srv(smdline : PChar; len : longint) : longint ; cdecl;

Implementation

//  rwcrun, rw2run - call interface for RUNREP (Reports Runtime char mode)

Function rwcrun(smdline : PChar) : longint ;  external 'R25OCI32.dll';
Function rw2run(smdline : PChar; len : longint) : longint ;  external 'R25OCI32.dll';

// rwcrrb, rw2rrb - call interface for RUNREP (Reports Runtime bitmapped)

Function rwcrrb(smdline : PChar) : longint ;  external 'R25OCI32.dll';
Function rw2rrb(smdline : PChar; len : longint) : longint ;  external 'R25OCI32.dll';

//  rwcsrb, rw2srb - call interface for SQLREP (Reports Designer bitmapped)

Function rwcsrb(smdline : PChar) : longint ;  external 'R25OCI32.dll';
Function rw2srb(smdline : PChar; len : longint) : longint ;  external 'R25OCI32.dll';

// rwccon, rw2con  - call interface for CONVREP (bitmapped)

Function rwccon(smdline : PChar) : longint ;  external 'R25OCI32.dll';
Function rw2con(smdline : PChar; len : longint) : longint ;  external 'R25OCI32.dll';

// rwcmov, rw2mov - call interface for MOVEREP (character mode)

Function rwcmov(smdline : PChar) : longint ;  external 'R25OCI32.dll';
Function rw2mov(smdline : PChar; len : longint) : longint ;  external 'R25OCI32.dll';

// rwcsrv, rw2srv - call interface for Report Server (Windows ONLY)

Function rwcsrv(smdline : PChar) : longint ;  external 'R25OCI32.dll';
Function rw2srv(smdline : PChar; len : longint) : longint ;  external 'R25OCI32.dll';


end.
